Project ETM topic centers and their top associated words to a two-dimensional space using the backend UMAP summary path, then visualize the result with ggplot2.
Value
A ggplot object.
Examples
if (FALSE) { # requireNamespace("topicmodels.etm", quietly = TRUE) && requireNamespace("torch", quietly = TRUE) && torch::torch_is_installed() && requireNamespace("uwot", quietly = TRUE)
path <- system.file(package = "topicmodels.etm", "example", "example_etm.ckpt")
model <- torch::torch_load(path)
plot_topic_embeddings(model, top_n = 5)
}